#### [BREAKING] The second argument `parsers` passed to `parsers.parse` has been removed (#13268 by @fisker)

The plugin's `print` function signature changed from

```ts
function parse(text: string, parsers: object, options: object): AST;
```

to

```ts
function parse(text: string, options: object): Promise<AST> | AST;
```

The second argument `parsers` has been removed, if you still need other parser during parse process, you can:

1. Import the plugin yourself

   ```js
   import pluginBabel from "prettier/plugins/babel";

   const myCustomPlugin = {
     parsers: {
       "my-custom-parser": {
         async parse(text) {
           const ast = await pluginBabel.parsers.babel.parse(text);
           ast.program.body[0].expression.callee.name = "_";
           return ast;
         },
         astFormat: "estree",
       },
     },
   };
   ```

1. Get the parser from the `options` argument

   ```js
   function getParserFromOptions(options, parserName) {
     const parserOrParserInitFunction = options.plugins.find((plugin) =>
       Object.hasOwn(plugin.parsers, parserName)
     )?.parsers[parserName];
     return typeof parserOrParserInitFunction === "function"
       ? parserOrParserInitFunction()
       : parserOrParserInitFunction;
   }

   const myCustomPlugin = {
     parsers: {
       "my-custom-parser": {
         async parse(text, options) {
           const babelParser = await getParserFromOptions(options, "babel");
           const ast = await babelParser.parse(text);
           ast.program.body[0].expression.callee.name = "_";
           return ast;
         },
         astFormat: "estree",
       },
     },
   };
   ```
